@@ -609,6 +609,21 @@ class MACAddressField(db.Field):
     def get_prep_value(self, value):
         return self.normalize(value)
 
+    def south_field_triple(self):
+        kwargs = dict(
+            null=self.null,
+            blank=self.blank,
+            choices=self.choices,
+            db_column=self.db_column,
+            db_index=self.db_index,
+            db_tablespace=self.db_tablespace,
+            default=self.default,
+            editable=self.editable,
+            primary_key=self.primary_key,
+            unique=self.unique,
+        )
+        return ('lck.django.common.models.MACAddressField', [], kwargs)
+
 
 # For now this needs to be at the end of the file.
 # FIXME: move it where it's supposed to be.
